@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/Documentation/RequirePodSections.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::Documentation::RequirePodSections;
 
 use 5.006001;
@@ -15,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :booleans :characters :severities :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -28,7 +21,7 @@ Readonly::Scalar my $M_S_PBP_0_0_3       => 'module_starter_pbp_0_0_3';
 
 Readonly::Scalar my $DEFAULT_SOURCE      => $BOOK_FIRST_EDITION;
 
-my %SOURCE_TRANSLATION  = (
+Readonly::Hash   my %SOURCE_TRANSLATION  => (
     $BOOK               => $BOOK_FIRST_EDITION,
     $BOOK_FIRST_EDITION => $BOOK_FIRST_EDITION,
     $MODULE_STARTER_PBP => $M_S_PBP_0_0_3,
@@ -241,7 +234,7 @@ sub _parse_sections {
 
     my @sections = split m{ \s* [|] \s* }xms, $config_string;
 
-    return map { uc $_ } @sections;  # Normalize CaSe!
+    return map { uc } @sections;  # Normalize CaSe!
 }
 
 sub _parse_lib_sections {
@@ -317,15 +310,20 @@ sub violates {
     my %found_sections = ();
     my @violations = ();
 
-    my @required_sections = is_script($doc) ? @{ $self->{_script_sections} }
-                                            : @{ $self->{_lib_sections} };
+    my @required_sections =
+        $doc->is_program()
+            ? @{ $self->{_script_sections} }
+            : @{ $self->{_lib_sections} };
 
     my $pods_ref = $doc->find('PPI::Token::Pod');
     return if not $pods_ref;
 
     # Round up the names of all the =head1 sections
+    my $pod_of_record;
     for my $pod ( @{ $pods_ref } ) {
         for my $found ( $pod =~ m{ ^ =head1 \s+ ( .+? ) \s* $ }gxms ) {
+            # Use first matching POD as POD of record (RT #59268)
+            $pod_of_record ||= $pod;
             #Leading/trailing whitespace is already removed
             $found_sections{ uc $found } = 1;
         }
@@ -335,7 +333,12 @@ sub violates {
     for my $required ( @required_sections ) {
         if ( not exists $found_sections{$required} ) {
             my $desc = qq{Missing "$required" section in POD};
-            push @violations, $self->violation( $desc, $EXPL, $doc );
+            # Report any violations against POD of record rather than whole
+            # document (the point of RT #59268)
+            # But if there are no =head1 records at all, rat out the
+            # first pod found, as being better than blowing up. RT #67231
+            push @violations, $self->violation( $desc, $EXPL,
+                $pod_of_record || $pods_ref->[0] );
         }
     }
 
@@ -381,15 +384,15 @@ of a perl shebang line).
                 Default Required POD Sections
 
     Perl Libraries                     Perl Programs
-    ------------------------------------------------------
+    -----------------------------      ---------------------
     NAME                               NAME
     VERSION
     SYNOPSIS                           USAGE
     DESCRIPTION                        DESCRIPTION
     SUBROUTINES/METHODS                REQUIRED ARGUMENTS
-                                        OPTIONS
+                                       OPTIONS
     DIAGNOSTICS                        DIAGNOSTICS
-                                        EXIT STATUS
+                                       EXIT STATUS
     CONFIGURATION AND ENVIRONMENT      CONFIGURATION
     DEPENDENCIES                       DEPENDENCIES
     INCOMPATIBILITIES                  INCOMPATIBILITIES
@@ -459,15 +462,21 @@ Currently, this Policy does not look for the required POD sections
 below the C<=head1> level.  Also, it does not require the sections to
 appear in any particular order.
 
+This Policy applies to the entire document, but can be disabled for a
+particular document by a C<## no critic (RequirePodSections)> annotation
+anywhere between the beginning of the document and the first POD section
+containing a C<=head1>, the C<__END__> (if any), or the C<__DATA__> (if any),
+whichever comes first.
+
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2006-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
