@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Utils/POD.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Utils::POD;
 
 use 5.006001;
@@ -22,9 +15,9 @@ use Perl::Critic::Exception::Fatal::Generic qw< throw_generic >;
 use Perl::Critic::Exception::IO qw< throw_io >;
 use Perl::Critic::Utils qw< :characters >;
 
-use base 'Exporter';
+use Exporter 'import';
 
-our $VERSION = '1.092';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -170,9 +163,6 @@ sub get_pod_section_for_module {
 sub _get_pod_section_from_file {
     my ($file_name, $section_name, $parser) = @_;
 
-    # Grr... the handle is open for a whopping 1 statement.  Too painful to
-    # fix the policy right now.
-    ## no critic (RequireBriefOpen)
     open my $file_handle, '<', $file_name
         or throw_io
             message     => qq<Could not open "$file_name": $ERRNO>,
@@ -189,7 +179,6 @@ sub _get_pod_section_from_file {
             message     => qq<Could not close "$file_name": $ERRNO>,
             file_name   => $file_name,
             errno       => $ERRNO;
-    ## use critic
 
     return $content;
 }
@@ -356,9 +345,6 @@ sub get_module_abstract_for_module {
 sub _get_module_abstract_from_file {
     my ($file_name, $parser, $trimmer) = @_;
 
-    # Grr... the handle is open for a whopping 1 statement.  Too painful to
-    # fix the policy right now.
-    ## no critic (RequireBriefOpen)
     open my $file_handle, '<', $file_name
         or throw_io
             message     => qq<Could not open "$file_name": $ERRNO>,
@@ -375,7 +361,6 @@ sub _get_module_abstract_from_file {
             message     => qq<Could not close "$file_name": $ERRNO>,
             file_name   => $file_name,
             errno       => $ERRNO;
-    ## use critic
 
     return $module_abstract;
 }
@@ -521,6 +506,12 @@ Perl::Critic::Utils::POD - Utility functions for dealing with POD.
 Provides means of accessing chunks of POD.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public module.  Any changes to its
+interface will go through a deprecation cycle.
+
+
 =head1 IMPORTABLE SUBROUTINES
 
 =over
@@ -704,7 +695,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2008-2011 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
